/**
 * Copyright (c) 2009, 2010 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.activerecord;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * Handles internationalized strings for the ActiveRecord package.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class ActiveRecordMessages {

	private static final String BUNDLE_NAME = "com.jdorm.activerecord.messages"; //$NON-NLS-1$

	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle.getBundle(BUNDLE_NAME);
	
	public static final String AbstractActiveRecord_CouldNotConnect = getString("AbstractActiveRecord_CouldNotConnect"); //$NON-NLS-1$
	public static final String AbstractActiveRecord_NoConnectionEstablished = getString("AbstractActiveRecord_NoConnectionEstablished"); //$NON-NLS-1$

	/**
	 * Private constructor since this class does not carry any state.
	 */
	private ActiveRecordMessages() {
	}

	/**
	 * Gets a string from the message bundle.
	 * 
	 * @param	key	The key for the string to get.
	 * 
	 * @return	The externalized string.
	 */
	public static String getString(String key) {
		try {
			return RESOURCE_BUNDLE.getString(key);
		} catch (MissingResourceException e) {
			return '!' + key + '!';
		}
	}
	
} // ActiveRecordMessages