/**
 * Copyright (c) 2009, 2010 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.datasource;

import com.jdorm.datasource.connectors.AbstractDataSourceConnector;
import com.jdorm.datasource.connectors.DB2DataSourceConnector;
import com.jdorm.datasource.connectors.MySQLDataSourceConnector;
import com.jdorm.datasource.connectors.ODBCDataSourceConnector;
import com.jdorm.datasource.connectors.OracleDataSourceConnector;
import com.jdorm.datasource.connectors.PostgreSQLDataSourceConnector;
import com.jdorm.datasource.connectors.SQLServerDataSourceConnector;
import com.jdorm.datasource.connectors.SQLiteDataSourceConnector;

/**
 * Represents the available data sources that can be utilized with this library.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public enum DataSourceType {
	
	DB2(new DB2DataSourceConnector()),
	MySQL(new MySQLDataSourceConnector()),
	ODBC(new ODBCDataSourceConnector()),
	Oracle(new OracleDataSourceConnector()),
	PostgreSQL(new PostgreSQLDataSourceConnector()),
	SQLite(new SQLiteDataSourceConnector()),
	SQLServer(new SQLServerDataSourceConnector()),
	JDBCDataSource(null);
	
	private AbstractDataSourceConnector connector;
	
	/**
	 * Creates a new DataSourceType associated with the specified connector.
	 * 
	 * @param	connector	The data source connector to associate with this type.
	 */
	private DataSourceType(AbstractDataSourceConnector connector) {
		this.connector = connector;
	}
	
	/**
	 * Gets the data source connector for this data source.
	 * 
	 * @return	A data source connector.
	 */
	public AbstractDataSourceConnector getConnector() {
		return connector;
	}
	
} // DataSourceType