/**
 * Copyright (c) 2009, 2010 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.datasource;

import java.util.Collections;
import java.util.List;

/**
 * Represents a row in a database.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class DatabaseRow {

	private int index;
	private List<Object> data;
	
	/**
	 * Creates a new row representing a row in a database.
	 * 
	 * @param	index	The index the row was when retrieved.
	 * @param	data	The data, ordered by the column order.
	 */
	public DatabaseRow(int index, List<Object> data) {
		this.index = index;
		this.data = data;
	}

	/**
	 * Gets the index.
	 *
	 * @return	The index.
	 */
	public int getIndex() {
		return index;
	}

	/**
	 * Gets the data at the specified column index.
	 * 
	 * @param	column	The zero-indexed column.
	 * 
	 * @return	The object at the specified column in the database row.
	 */
	public Object getData(int column) {
		Object retVal = null;
		if (column >= 0 && column < data.size()) {
			retVal = data.get(column);
		}
		return retVal;
	}
	
	/**
	 * Gets the data.
	 *
	 * @return	The data.
	 */
	public List<Object> getData() {
		return Collections.unmodifiableList(data);
	}
	
} // DatabaseRow