/**
 * Copyright (c) 2009, 2010 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.datasource;

/**
 * Represents a key that was generated from a statement being run.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class GeneratedKey {

	private String column;
	private int type;
	private Object data;
	
	/**
	 * Creates a new GeneratedKey object.
	 * 
	 * @param	column	The column name for the generated key.
	 * @param	type	The type of column (Can be compared with the java.sql.Types class).
	 * @param	data	The data that was generated.
	 */
	public GeneratedKey(String column, int type, Object data) {
		this.column = column;
		this.type = type;
		this.data = data;
	}

	/**
	 * Gets the column.
	 *
	 * @return	The column.
	 */
	public String getColumn() {
		return column;
	}

	/**
	 * Gets the type.
	 *
	 * @return	The type.
	 */
	public int getType() {
		return type;
	}

	/**
	 * Gets the data.
	 *
	 * @return	The data.
	 */
	public Object getData() {
		return data;
	}
	
} // GeneratedKey