/**
 * Copyright (c) 2009, 2010 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.datasource.connectors;

/**
 * Provides the necessary information to connect to a database.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public abstract class AbstractDataSourceConnector {

	public static final String DEFAULT_HOST = "localhost"; //$NON-NLS-1$

	/**
	 * Gets the JDBC connection fragment for the data source.
	 * 
	 * @return	The JDBC connection fragment.
	 */
	public String getConnectionFragment() {
		return "jdbc:" + getAdapter() + "://"; //$NON-NLS-1$ //$NON-NLS-2$
	}
	
	/**
	 * Gets the full JDBC connection URL for the specified database.
	 * 
	 * @param	host	The host to get the URL for.
	 * @param	port	The port to connect through.
	 * @param	database	The database to connect to.
	 * 
	 * @return	The connection URL for the specified database.
	 */
	public String getUrl(String host, String port, String database) {
		return getConnectionFragment() + host + ":" + port + "/" + database; //$NON-NLS-1$ //$NON-NLS-2$
	}
	
	/**
	 * Gets the full JDBC connection URL for the specified database
	 * on the default host (localhost) and port (dependent on data source).
	 * 
	 * @param	database	The database to connect to.
	 * 
	 * @return	The connection URL for the specified database.
	 */
	public String getUrl(String database) {
		return getUrl(DEFAULT_HOST, String.valueOf(getDefaultPort()), database);
	}
	
	/**
	 * Gets the JDBC connection adapter name. This is typically what
	 * immediately follows "jdbc:".
	 * 
	 * @return	The JDBC connection adapter name.
	 */
	public abstract String getAdapter();
	
	/**
	 * Gets the default port used by the data source.
	 * 
	 * @return	The default port of the data source.
	 */
	public abstract int getDefaultPort();
	
	/**
	 * Gets the JDBC driver class name to be used to connect
	 * to the appropriate Connector/J class.
	 * 
	 * @return	The fully qualified string to of the class.
	 */
	public abstract String getDriver();
	
} // AbstractDataSourceConnector