/**
 * Copyright (c) 2009, 2010 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.inflection;

import java.util.regex.Pattern;

/**
 * Represents a rule used by the Inflector to replace
 * a specified expression with the replacement string.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class InflectionRule {

	private Pattern pattern;
	private String replacement;
	
	/**
	 * Creates a new rule based on the pattern and replacement expression.
	 * 
	 * @param	pattern	A regular expression representing the pattern.
	 * @param	replacement	A regular expression representing the replacement.
	 */
	public InflectionRule(String pattern, String replacement) {
		this.pattern = Pattern.compile(pattern, Pattern.CASE_INSENSITIVE);
		this.replacement = replacement;
	}
	
	/**
	 * Determines whether the specified word is a match against this rule.
	 * 
	 * @param	word	The word to test.
	 * 
	 * @return	<code>true</code> if the word fits this rule,
	 * 			<code>false</code> otherwise.
	 */
	public boolean isMatch(String word) {
		return pattern.matcher(word).find();
	}
	
	/**
	 * Replaces word with the replacement pattern.
	 * 
	 * @param	word	The word to apply the rule against.
	 * 
	 * @return	The word modified based on the replacement pattern.
	 */
	public String apply(String word) {
		return pattern.matcher(word).replaceAll(replacement);
	}
	
} // InflectionRule