/**
 * Copyright (c) 2009, 2010 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.util;

/**
 * Provides functions for modifying strings.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class StringUtil {

	/**
	 * Private constructor since this is a utility class.
	 */
	private StringUtil() {}
	
	/**
	 * Converts a string to camel case. This will remove spaces and underscores
	 * and replace the character following them with its uppercase version.
	 * 
	 * @param	str	The string to convert.
	 * 
	 * @return	The camel case version of str.
	 */
	public static String toCamelCase(String str) {
		str = str.trim();
		StringBuilder builder = new StringBuilder();
		boolean shouldUppercase = false;
		for (int i = 0; i < str.length(); i++) {
			char currChar = str.charAt(i);
			if (Character.isWhitespace(currChar) || currChar == '_') {
				shouldUppercase = true;
			} else {
				if (i == 0 || shouldUppercase) {
					builder.append(Character.toUpperCase(currChar));
					shouldUppercase = false;
				} else {
					builder.append(Character.toLowerCase(currChar));
				}
			}
		}
		return builder.toString();
	}
	
} // StringUtil