/**
 * Copyright (c) 2009, 2011 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.activerecord;

import static org.junit.Assert.*;

import org.junit.Test;

/**
 * Tests the Conditions class.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class ConditionsTest {

	/**
	 * Test method for {@link com.jdorm.activerecord.Conditions#where(java.lang.String)}.
	 */
	@Test
	public void testWhere() {
		Conditions conditions = Conditions.where("username = ?", "mbaumbach"); //$NON-NLS-1$
		assertEquals("WHERE username = ?", conditions.toString()); //$NON-NLS-1$
		assertArrayEquals(new Object[] { "mbaumbach" }, conditions.getParameters()); //$NON-NLS-1$
	}

	/**
	 * Test method for {@link com.jdorm.activerecord.Conditions#order(java.lang.String)}.
	 */
	@Test
	public void testOrder() {
		Conditions conditions = Conditions.order("first_name DESC"); //$NON-NLS-1$
		assertEquals("ORDER BY first_name DESC", conditions.toString()); //$NON-NLS-1$
	}

	/**
	 * Test method for {@link com.jdorm.activerecord.Conditions#group(java.lang.String)}.
	 */
	@Test
	public void testGroup() {
		Conditions conditions = Conditions.group("last_name"); //$NON-NLS-1$
		assertEquals("GROUP BY last_name", conditions.toString()); //$NON-NLS-1$
	}

	/**
	 * Test method for {@link com.jdorm.activerecord.Conditions#having(java.lang.String)}.
	 */
	@Test
	public void testHaving() {
		Conditions conditions = Conditions.having("age > ?", 10); //$NON-NLS-1$
		assertEquals("", conditions.toString()); //$NON-NLS-1$
		conditions.setGroup("last_name"); //$NON-NLS-1$
		assertEquals("GROUP BY last_name HAVING age > ?", conditions.toString()); //$NON-NLS-1$
		assertArrayEquals(new Object[] { Integer.valueOf(10) }, conditions.getParameters());
	}
	
	/**
	 * Test method for {@link com.jdorm.activerecord.Conditions#toString()}.
	 */
	@Test
	public void testToString() {
		Conditions condition1 = Conditions.where("username = ?", "mbaumbach").setOrder("first_name DESC").setGroup("last_name").setHaving("age > ?", 10); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
		Conditions condition2 = Conditions.group("last_name").setOrder("first_name DESC").setHaving("age > ?", 10).setWhere("username = ?", "mbaumbach"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
		assertEquals("WHERE username = ? ORDER BY first_name DESC GROUP BY last_name HAVING age > ?", condition1.toString()); //$NON-NLS-1$
		assertArrayEquals(new Object[] { "mbaumbach", Integer.valueOf(10) }, condition1.getParameters());
		assertEquals(condition1.toString(), condition2.toString());
		assertArrayEquals(condition1.getParameters(), condition2.getParameters());
	}

	/**
	 * Test method for {@link com.jdorm.activerecord.Conditions#equals(java.lang.Object)}.
	 */
	@Test
	public void testEqualsObject() {
		Conditions condition1 = Conditions.where("username = ?", "mbaumbach").setOrder("first_name DESC").setGroup("last_name").setHaving("age > ?", 10); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
		Conditions condition2 = Conditions.group("last_name").setOrder("first_name DESC").setHaving("age > ?", 10).setWhere("username = ?", "mbaumbach"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
		assertEquals(condition1, condition2);
	}
	
	/**
	 * Test method for {@link com.jdorm.activerecord.Conditions#hashCode()}.
	 */
	@Test
	public void testHashCode() {
		Conditions condition1 = Conditions.where("username = ?", "mbaumbach").setOrder("first_name DESC").setGroup("last_name").setHaving("age > ?", 10); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
		Conditions condition2 = Conditions.group("last_name").setOrder("first_name DESC").setHaving("age > ?", 10).setWhere("username = ?", "mbaumbach"); //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$ //$NON-NLS-4$ //$NON-NLS-5$
		assertEquals(condition1.hashCode(), condition2.hashCode());
	}

} // ConditionsTest