/**
 * Copyright (c) 2009, 2011 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.datasource;

import static org.junit.Assert.*;

import java.sql.Connection;
import java.sql.SQLException;

import org.junit.Before;
import org.junit.Test;

/**
 * Tests the DatabaseConnectionManager class.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class DatabaseConnectionManagerTest {

	private static final String DATABASE = "mysql"; //$NON-NLS-1$
	private static final String USER = "root"; //$NON-NLS-1$
	private static final String PASSWORD = ""; //$NON-NLS-1$
	
	private DatabaseDescriptor descriptor;
	
	/**
	 * Setup Log4J and attempt to connect to a basic MySQL database using relatively
	 * default parameters.
	 */
	@Before
	public void setUp() {
		descriptor = new DatabaseDescriptor(DataSourceType.MySQL, DatabaseConnectionManagerTest.DATABASE, DatabaseConnectionManagerTest.USER, DatabaseConnectionManagerTest.PASSWORD);
	}

	/**
	 * Test method for {@link com.jdorm.datasource.DatabaseConnectionManager#getConnection(com.jdorm.datasource.DatabaseDescriptor)}.
	 */
	@Test
	public void testGetConnection() {
		Connection connection = DatabaseConnectionManager.getInstance().getConnection(descriptor);
		assertNotNull(connection);
		try {
			assertFalse(connection.isClosed());
		} catch (SQLException e) {
			fail(e.getMessage());
		}
		// Attempt to get the connection again and verify we got the same connection object
		assertEquals(connection, DatabaseConnectionManager.getInstance().getConnection(descriptor));
	}
	
	/**
	 * Test method for {@link com.jdorm.datasource.DatabaseConnectionManager#closeConnection(com.jdorm.datasource.DatabaseDescriptor)}.
	 */
	@Test
	public void testCloseConnection() {
		Connection connection = DatabaseConnectionManager.getInstance().getConnection(descriptor);
		try {
			assertFalse(connection.isClosed());
		} catch (SQLException e) {
			fail(e.getMessage());
		}
		assertTrue(DatabaseConnectionManager.getInstance().closeConnection(descriptor));
		try {
			assertTrue(connection.isClosed());
		} catch (SQLException e) {
			fail(e.getMessage());
		}
	}

} // DatabaseConnectionManagerTest