/**
 * Copyright (c) 2009, 2011 jDORM, http://www.jdorm.com
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package com.jdorm.datasource;

import static org.junit.Assert.*;

import java.sql.Types;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
 * Tests the QueryAdministrator class. This test assumes a MySQL
 * database on the localhost with a user named "root" with no
 * password and the default mysql table is visible to the
 * root user.
 *
 * @author	mbaumbach
 *
 * @version	1.0
 */
public class QueryAdministratorTest {
	
	private static final String DATABASE = "mysql"; //$NON-NLS-1$
	private static final String USER = "root"; //$NON-NLS-1$
	private static final String PASSWORD = ""; //$NON-NLS-1$
	
	private QueryAdministrator administrator;

	@Before
	public void setUp() {
		administrator = new QueryAdministrator(new DatabaseDescriptor(DataSourceType.MySQL, QueryAdministratorTest.DATABASE, QueryAdministratorTest.USER, QueryAdministratorTest.PASSWORD));
	}

	@After
	public void tearDown() {
		DatabaseConnectionManager.getInstance().closeConnection(administrator.getDatabaseDescriptor());
	}

	/**
	 * Test method for {@link com.jdorm.datasource.QueryAdministrator#executeAndGetResult(java.lang.String)}.
	 */
	@Test
	public void testExecuteAndGetResultString() {
		QueryResult result = administrator.executeAndGetResult("SELECT * FROM user"); //$NON-NLS-1$
		assertNotNull(result);
		boolean foundUser = false;
		for (DatabaseRow row : result.getRows()) {
			if (row.getData().get(1).equals(USER)) {
				foundUser = true;
				break;
			}
		}
		assertTrue(foundUser);
	}

	/**
	 * Test method for {@link com.jdorm.datasource.QueryAdministrator#getLastResult()}.
	 */
	@Test
	public void testGetLastResult() {
		assertTrue(administrator.execute("SELECT * FROM user")); //$NON-NLS-1$
		assertNotNull(administrator.getLastResult());
	}

	/**
	 * Test method for {@link com.jdorm.datasource.QueryAdministrator#getTables()}.
	 */
	@Test
	public void testGetTables() {
		boolean foundTable = false;
		for (String table : administrator.getTables()) {
			if (table.equals("user")) { //$NON-NLS-1$
				foundTable = true;
				break;
			}
		}
		assertTrue(foundTable);
	}

	/**
	 * Test method for {@link com.jdorm.datasource.QueryAdministrator#getColumns(java.lang.String)}.
	 */
	@Test
	public void testGetColumns() {
		boolean foundHost = false;
		boolean foundUser = false;
		boolean foundPassword = false;
		for (DatabaseColumn column : administrator.getColumns("user")) { //$NON-NLS-1$
			if (column.getName().equals("Host") && column.getType() == Types.CHAR) { //$NON-NLS-1$
				foundHost = true;
			} else if (column.getName().equals("User") && column.getType() == Types.CHAR) { //$NON-NLS-1$
				foundUser = true;
			} else if (column.getName().equals("Password") && column.getType() == Types.CHAR) { //$NON-NLS-1$
				foundPassword = true;
			}
		}
		assertTrue(foundHost);
		assertTrue(foundUser);
		assertTrue(foundPassword);
	}

	/**
	 * Test method for {@link com.jdorm.datasource.QueryAdministrator#isPrimaryKey(java.lang.String, java.lang.String)}.
	 */
	@Test
	public void testIsPrimaryKey() {
		assertTrue(administrator.isPrimaryKey("Host", "user")); //$NON-NLS-1$ //$NON-NLS-2$
		assertTrue(administrator.isPrimaryKey("User", "user")); //$NON-NLS-1$ //$NON-NLS-2$
	}

} // QueryAdministratorTest